@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-26 15:26:32
-@LastEditTime: 2022-02-16 19:13:25
+@LastEditTime: 2022-02-24 11:04:16
 @LastEditors: HuangJianYi
 :Description: 活动处理
 """
@@ -51,11 +51,11 @@ class MachineListHandler(SevenBaseHandler):
         params = [act_id]
 
         if price_gear_id > 0:
-            condition += " AND price_gears_id=%s"
+            condition += " AND price_gears_id=%s AND machine_type=2"
             params.append(price_gear_id)
         if integral_gear_id > 0:
-            condition += " AND machine_price=%s"
-            params.append(str(price_gear_id)+".00")
+            condition += " AND machine_price=%s AND machine_type=3"
+            params.append(str(integral_gear_id) + ".00")
         if series_id > 0:
             condition += " AND series_id=%s"
             params.append(series_id)
