@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2022-03-01 17:02:49
+@LastEditTime: 2022-05-05 09:27:59
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -521,7 +521,7 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
                     false_act_prize_list = ActPrizeModel(context=self).get_list("act_id=%s and machine_id in (" + machine_ids + ") and is_prize_notice=1", order_by="probability desc", limit="30", params=[act_id])
                 if len(false_act_prize_list) > 0 and addNum > 0:
                     now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                    user_info_list_dict = UserInfoModel(context=self).get_dict_list("app_id!=%s and user_nick!='' and create_date>%s", params=[app_id, now_datetime], limit=str(addNum))
+                    user_info_list_dict = UserInfoModel(context=self).get_dict_list("is_auth=1 and create_date>%s", params=[now_datetime], limit=str(addNum))
                     random_Prize_dict_list = {}
                     for act_prize in false_act_prize_list:
                         random_Prize_dict_list[act_prize.id] = act_prize.probability
