@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2022-02-24 15:22:47
+@LastEditTime: 2022-07-13 09:53:57
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -17,7 +17,6 @@ from seven_cloudapp.models.db_models.act.act_type_model import *
 from seven_cloudapp.models.db_models.ip.ip_series_model import *
 
 from seven_cloudapp.handlers.server.act_s import ActTypeListHandler
-from seven_cloudapp.handlers.server.act_s import ActDelHandler
 from seven_cloudapp.handlers.server.act_s import ActQrCodeHandler
 from seven_cloudapp.handlers.server.act_s import ActReviewHandler
 from seven_cloudapp.handlers.server.act_s import NextProgressHandler
@@ -25,6 +24,8 @@ from seven_cloudapp.handlers.server.act_s import NextProgressHandler
 from seven_cloudapp_ppmt.models.db_models.machine.machine_info_model import *
 from seven_cloudapp_ppmt.models.db_models.act.act_prize_model import *
 from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
+from seven_cloudapp_ppmt.models.db_models.launch.launch_plan_model import *
+from seven_cloudapp_ppmt.models.db_models.launch.launch_goods_model import *
 
 
 class ActCreateHandler(TopBaseHandler):
@@ -459,4 +460,75 @@ class ActInfoHandler(SevenBaseHandler):
 
             return self.reponse_json_success(act_info)
 
-        return self.reponse_json_success()
\ No newline at end of file
+        return self.reponse_json_success()
+
+
+class ActDelHandler(SevenBaseHandler):
+    """
+    :description: 删除或者还原活动
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 删除或者还原活动
+        :param act_id：活动id
+        :param is_del：0-还原，1-删除
+        :return: 
+        :last_editors: HuangJingCan
+        """
+        act_id = int(self.get_param("act_id", 0))
+        is_del = int(self.get_param("is_del", 1))
+        access_token = self.get_param("access_token")
+        modify_date = self.get_now_datetime()
+        if act_id <= 0:
+            return self.reponse_json_error_params()
+        is_release = 0 if is_del == 1 else 1
+
+        del_launch = config.get_value("del_launch",0)
+        if del_launch == 1:
+            launch_plan_model = LaunchPlanModel(context=self)
+            launch_plan = launch_plan_model.get_entity("act_id=%s", order_by="id desc", params=[act_id])
+            if launch_plan:
+                invoke_result_data = self.get_launch_action_info(launch_plan.tb_launch_id, access_token)
+
+                if invoke_result_data["success"] == True:
+                    tb_launch_status = invoke_result_data["data"]["miniapp_distribution_order_get_response"]["model"]["distribution_order_open_biz_dto"][0]["status"]
+                    if tb_launch_status != 2:
+                        return self.reponse_json_error("error", "请先中止投放计划")
+            act_info_model = ActInfoModel(context=self)
+            act_info_model.update_table("is_launch=0", "id=%s", params=[act_id])
+            LaunchGoodsModel(context=self).del_entity("act_id=%s", params=[act_id])
+
+        act_info_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, act_id])
+        return self.reponse_json_success()
+
+    def get_launch_action_info(self, order_id, access_token):
+
+        invoke_result_data = {"success": True, "error_code": "", "error_message": ""}
+        app_key, app_secret = self.get_app_key_secret()
+        try:
+
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappDistributionOrderGetRequest()
+            req.order_id_request = {}
+            req.order_id_request["order_id_list"] = [order_id]
+
+            resp = req.getResponse(access_token)
+            invoke_result_data["data"] = resp
+            return invoke_result_data
+
+        except Exception as ex:
+            self.logging_link_error("GetLaunchActionInfo:" + traceback.format_exc())
+            invoke_result_data["success"] = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data["error_code"] = "no_power"
+                        invoke_result_data["error_message"] = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data["error_code"] = "error"
+                        invoke_result_data["error_message"] = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
\ No newline at end of file
