@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-03-01 17:03:02
+@LastEditTime: 2022-07-13 10:08:30
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -82,6 +82,17 @@ def seven_cloudapp_ppmt_route():
         (r"/server/init_throw_goods_list", throw_s.InitThrowGoodsListHandler),
         (r"/server/save_throw_goods_status", throw_s.SaveThrowGoodsStatusHandler),
         (r"/server/init_throw_goods_callback", throw_s.InitThrowGoodsCallBackHandler),
+        (r"/server/get_launch_plan_status", launch_s.GetLaunchPlanStatusHandler),  #获取投放计划状态
+        (r"/server/reset_launch_goods", launch_s.ResetLaunchGoodsHandler),  #重置商品投放 删除已投放的记录并将活动投放状态改为未投放
+        (r"/server/add_launch_goods_list", launch_s.AddLaunchGoodsListHandler),  #添加投放商品
+        (r"/server/async_launch_goods_status", launch_s.AsyncLaunchGoodsStatusHandler),  #同步投放商品状态
+        (r"/server/can_launch_goods_list", launch_s.CanLaunchGoodsListHandler),  #获取可投放商品列表（获取当前会话用户出售中的商品列表）
+        (r"/server/get_launch_progress", launch_s.GetLaunchProgressHandler),  #获取投放进度
+        (r"/server/init_launch_goods_list", launch_s.InitLaunchGoodsHandler),  #初始化活动投放
+        (r"/server/init_launch_goods_callback", launch_s.InitLaunchGoodsCallBackHandler),  #初始化投放商品回调接口
+        (r"/server/save_launch_goods_status", launch_s.UpdateLaunchGoodsStatusHandler),  #保存更改投放商品的状态
+        (r"/server/launch_goods_list", launch_s.LaunchGoodsListHandler),  #投放商品列表
+        (r"/server/async_launch_goods", launch_s.AsyncLaunchGoodsStatusHandler),  #同步投放商品列表
         # 2.0
         (r"/server/get_power_menu", power_s.GetPowerMenuHandler),
         (r"/server/task", task_s.TaskSaveHandler),
